==> react-native-popup-confirm-toast-1.0.6.tgz: package/src/main/Popup.js <==
import React, {Component} from 'react';
import {Animated, Dimensions, Image, StyleSheet, Text, TouchableOpacity, View} from 'react-native';

const WIDTH = Dimensions.get('window').width;
const HEIGHT = Dimensions.get('window').height;

class Popup extends Component {
    static popupInstance;
    state = {
        positionView: new Animated.Value(HEIGHT),
        opacity: new Animated.Value(0),
        positionPopup: new Animated.Value(HEIGHT),
        popupHeight: 0,
    };

    static show({...config}) {
        this.popupInstance.start(config);
    }

    static hide() {
        this.popupInstance.hidePopup();
    }

    start({...config}) {
        this.setState({
            title: config.title || false,
            type: config.type || 'warning',
            buttonEnabled: config.buttonEnabled === false ? false : true,
            textBody: config.textBody,
            buttonText: config.buttonText || 'Ok',
            confirmText: config.confirmText || 'Cancel',
            callback: config.callback !== undefined ? config.callback : this.hidePopup(),
            background: config.background || 'rgba(0, 0, 0, 0.5)',
            timing: config.timing || 0,
            iconEnabled: config.iconEnabled === false ? false : true,
            successIcon: config.successIcon || require('../assets/success.png'),
            errorIcon: config.errorIcon || require('../assets/error.png'),
            warningIcon: config.warningIcon || require('../assets/warning.png'),
            confirmIcon: config.confirmIcon || require('../assets/warning.png'),
            buttonContentStyle: config.buttonContentStyle || false,
            successButtonStyle: config.successButtonStyle || false,
            dangerButtonStyle: config.dangerButtonStyle || false,
            warningButtonStyle: config.warningButtonStyle || false,
            titleTextStyle: config.titleTextStyle || false,
            descTextStyle: config.descTextStyle || false,
            okButtonTextStyle: config.okButtonTextStyle || false,
            confirmButtonTextStyle: config.confirmButtonTextStyle || false,
        });

        Animated.sequence([
            Animated.timing(this.state.positionView, {
                toValue: 0,
                duration: 100,
                useNativeDriver: false,
            }),
            Animated.timing(this.state.opacity, {
                toValue: 1,
                duration: 300,
                useNativeDriver: false,
            }),
            Animated.spring(this.state.positionPopup, {
                toValue: (HEIGHT / 2) - (this.state.popupHeight / 2),
                bounciness: 15,
                useNativeDriver: true,
            }),
        ]).start();

        if (config.timing !== 0) {
            const duration = config.timing > 0 ? config.timing : 5000;
            setTimeout(() => {
                this.hidePopup();
            }, duration);
        }
    }

    hidePopup() {
        Animated.sequence([
            Animated.timing(this.state.positionPopup, {
                toValue: HEIGHT,
                duration: 250,
                useNativeDriver: true,
            }),
            Animated.timing(this.state.opacity, {
                toValue: 0,
                duration: 300,
                useNativeDriver: false,
            }),
            Animated.timing(this.state.positionView, {
                toValue: HEIGHT,
                duration: 100,
                useNativeDriver: false,
            }),
        ]).start();
    }

    handleImage(type) {
        switch (type) {
            case 'success':
                return this.state.successIcon || require('../assets/success.png');
            case 'danger':
                return this.state.errorIcon || require('../assets/error.png');
            case 'warning':
                return this.state.warningIcon || require('../assets/warning.png');
            case 'confirm':
                return this.state.confirmIcon || require('../assets/warning.png');
        }
    }

    render() {
        const {title, type, textBody, buttonEnabled, buttonText, confirmText, callback, background, iconEnabled} = this.state;

        return (
            <Animated.View
                ref={c => this._root = c}
                style={[styles.Container, {
                    backgroundColor: background || 'transparent',
                    opacity: this.state.opacity,
                    transform: [
                        {translateY: this.state.positionView},
                    ],
                }]}>
                <Animated.View
                    onLayout={event => {
                        this.setState({popupHeight: event.nativeEvent.layout.height});
                    }}
                    style={[styles.Message, {
                        transform: [
                            {translateY: this.state.positionPopup},
                        ],
                    }]}

                >
                    {
                        iconEnabled && (
                            <>
                                <View style={styles.Header}/>
                                <Image
                                    source={this.handleImage(type)}
                                    resizeMode="contain"
                                    style={styles.Image}
                                />
                            </>
                        )
                    }

                    <View style={styles.Content}>
                        {
                            title && title.length > 0 && (
                                <Text style={[styles.Title, this.state.titleTextStyle]}>{title}</Text>
                            )
                        }
                        <Text style={[styles.Desc, this.state.descTextStyle]}>{textBody}</Text>
                        <View style={this.state.buttonContentStyle}>
                            {
                                buttonEnabled && (
                                    <TouchableOpacity style={[styles.Button, styles[type + 'ButtonStyle']]} onPress={() => callback()}>
                                        <Text style={[styles.TextButton, this.state.okButtonTextStyle]}>{buttonText}</Text>
                                    </TouchableOpacity>
                                )
                            }
                            {
                                type === 'confirm' && (
                                    <TouchableOpacity style={[styles.Button, styles[type]]} onPress={() => this.hidePopup()}>
                                        <Text style={[styles.TextButton, styles[type + 'Text'], this.state.confirmButtonTextStyle]}>{confirmText}</Text>
                                    </TouchableOpacity>
                                )
                            }
                        </View>
                    </View>
                </Animated.View>
            </Animated.View>
        );
    }
}

const styles = StyleSheet.create({
    Container: {
        position: 'absolute',
        zIndex: 9,
        width: WIDTH,
        height: HEIGHT,
        backgroundColor: 'rgba(0, 0, 0, 0.5)',
        alignItems: 'center',
        top: 0,
        left: 0,
    },
    Message: {
        width: '90%',
        backgroundColor: '#fff',
        borderRadius: 8,
        alignItems: 'center',
        overflow: 'hidden',
        position: 'absolute',
    },
    Content: {
        padding: 20,
        width: '100%',
    },
    Header: {
        height: 75,
        width: 100,
        backgroundColor: '#fff',
    },
    Image: {
        width: 48,
        height: 48,
        position: 'absolute',
        top: 20,
    },
    Title: {
        color: '#1e1e1e',
        fontSize: 18,
        fontWeight: '600',
        fontStyle: 'normal',
        textAlign: 'center',
        lineHeight: 24,
        marginBottom: 10,
    },
    Desc: {
        color: '#111111',
        fontSize: 16,
        fontWeight: '400',
        fontStyle: 'normal',
        textAlign: 'center',
        lineHeight: 24,
    },
    Button: {
        flex: 1,
        height: 48,
        justifyContent: 'center',
        alignItems: 'center',
        marginTop: 20,
        borderRadius: 8,
        backgroundColor: '#702c91',
    },
    TextButton: {
        color: '#ffffff',
        fontFamily: 'AvenirNext-DemiBold',
        fontSize: 16,
        fontWeight: '600',
        fontStyle: 'normal',
        textAlign: 'center',
        lineHeight: 20,
    },
    successButtonStyle: {
        backgroundColor: '#702c91',
    },
    dangerButtonStyle: {
        backgroundColor: '#702c91',
    },
    warningButtonStyle: {
        backgroundColor: '#702c91',
    },
    confirm: {
        backgroundColor: 'transparent',
        color: '#111111',
    },
    confirmText: {
        color: '#111111',
    },

});

export default Popup;

==> react-native-popup-confirm-toast-1.0.7.tgz: package/src/main/Popup.js <==
import React, {Component} from 'react';
import {Animated, Dimensions, Image, StyleSheet, Text, TouchableOpacity, View} from 'react-native';

export const {width: WIDTH, height: HEIGHT} = Dimensions.get('window');

class Popup extends Component {
    static popupInstance;
    state = {
        positionView: new Animated.Value(HEIGHT),
        opacity: new Animated.Value(0),
        positionPopup: new Animated.Value(HEIGHT),
        popupHeight: 0,
    };

    static show({...config}) {
        this.popupInstance.start(config);
    }

    static hide() {
        this.popupInstance.hidePopup();
    }

    start({...config}) {
        console.log('start', 1);
        this.setState({
            title: config.title || false,
            type: config.type || 'warning',
            buttonEnabled: config.buttonEnabled === false ? false : true,
            textBody: config.textBody,
            buttonText: config.buttonText || 'Ok',
            confirmText: config.confirmText || 'Cancel',
            callback: config.callback !== undefined ? config.callback : this.hidePopup(),
            background: config.background || 'rgba(0, 0, 0, 0.5)',
            timing: config.timing || 0,
            iconEnabled: config.iconEnabled === false ? false : true,
            successIcon: config.successIcon || require('../assets/success.png'),
            errorIcon: config.errorIcon || require('../assets/error.png'),
            warningIcon: config.warningIcon || require('../assets/warning.png'),
            confirmIcon: config.confirmIcon || require('../assets/warning.png'),
            buttonContentStyle: config.buttonContentStyle || false,
            successButtonStyle: config.successButtonStyle || false,
            dangerButtonStyle: config.dangerButtonStyle || false,
            warningButtonStyle: config.warningButtonStyle || false,
            titleTextStyle: config.titleTextStyle || false,
            descTextStyle: config.descTextStyle || false,
            okButtonTextStyle: config.okButtonTextStyle || false,
            confirmButtonTextStyle: config.confirmButtonTextStyle || false,
            popupHeight: config.popupHeight || 0,
            start: true,
        });
    }

    startPopup() {
        this.setState({
            start: false,
        }, () => {
            Animated.sequence([
                Animated.timing(this.state.positionView, {
                    toValue: 0,
                    duration: 100,
                    useNativeDriver: false,
                }),
                Animated.timing(this.state.opacity, {
                    toValue: 1,
                    duration: 300,
                    useNativeDriver: false,
                }),
                Animated.spring(this.state.positionPopup, {
                    toValue: (HEIGHT / 2) - (this.state.popupHeight / 2),
                    bounciness: 15,
                    useNativeDriver: true,
                }),
            ]).start();

            if (this.state.timing !== 0) {
                const duration = this.state.timing > 0 ? this.state.timing : 5000;
                setTimeout(() => {
                    this.hidePopup();
                }, duration);
            }
        });
    }

    hidePopup() {
        Animated.sequence([
            Animated.timing(this.state.positionPopup, {
                toValue: HEIGHT,
                duration: 250,
                useNativeDriver: true,
            }),
            Animated.timing(this.state.opacity, {
                toValue: 0,
                duration: 300,
                useNativeDriver: false,
            }),
            Animated.timing(this.state.positionView, {
                toValue: HEIGHT,
                duration: 100,
                useNativeDriver: false,
            }),
        ]).start(() => {
            this.setState({
                start: false,
                title: false,
                textBody: false,
            });
        });
    }

    handleImage(type) {
        switch (type) {
            case 'success':
                return this.state.successIcon || require('../assets/success.png');
            case 'danger':
                return this.state.errorIcon || require('../assets/error.png');
            case 'warning':
                return this.state.warningIcon || require('../assets/warning.png');
            case 'confirm':
                return this.state.confirmIcon || require('../assets/warning.png');
        }
    }

    render() {
        const {title, type, textBody, buttonEnabled, buttonText, confirmText, callback, background, iconEnabled, start} = this.state;

        return (
            <Animated.View
                ref={c => this._root = c}
                style={[styles.Container, {
                    backgroundColor: background || 'transparent',
                    opacity: this.state.opacity,
                    transform: [
                        {translateY: this.state.positionView},
                    ],
                }]}>
                <Animated.View
                    onLayout={event => {
                        const height = event.nativeEvent.layout.height;
                        this.setState({popupHeight: height}, () => {
                            if (start) {
                                this.startPopup();
                            }
                        });
                    }}
                    style={[styles.Message, {
                        transform: [
                            {translateY: this.state.positionPopup},
                        ],
                    }]}
                >
                    {
                        iconEnabled && (
                            <>
                                <View style={styles.Header}/>
                                <Image
                                    source={this.handleImage(type)}
                                    resizeMode="contain"
                                    style={styles.Image}
                                />
                            </>
                        )
                    }
                    <View style={styles.Content}>
                        {
                            title && title.length > 0 && (
                                <Text style={[styles.Title, this.state.titleTextStyle]}>{title}</Text>
                            )
                        }
                        <Text style={[styles.Desc, this.state.descTextStyle]}>{textBody}</Text>
                        <View style={this.state.buttonContentStyle}>
                            {
                                buttonEnabled && (
                                    <TouchableOpacity style={[styles.Button, styles[type + 'ButtonStyle']]} onPress={() => callback()}>
                                        <Text style={[styles.TextButton, this.state.okButtonTextStyle]}>{buttonText}</Text>
                                    </TouchableOpacity>
                                )
                            }
                            {
                                type === 'confirm' && (
                                    <TouchableOpacity style={[styles.Button, styles[type]]} onPress={() => this.hidePopup()}>
                                        <Text style={[styles.TextButton, styles[type + 'Text'], this.state.confirmButtonTextStyle]}>{confirmText}</Text>
                                    </TouchableOpacity>
                                )
                            }
                        </View>
                    </View>
                </Animated.View>
            </Animated.View>
        );
    }
}

const styles = StyleSheet.create({
    Container: {
        position: 'absolute',
        zIndex: 9,
        width: WIDTH,
        height: HEIGHT,
        backgroundColor: 'rgba(0, 0, 0, 0.5)',
        alignItems: 'center',
        top: 0,
        left: 0,
    },
    Message: {
        width: '90%',
        backgroundColor: '#fff',
        borderRadius: 8,
        alignItems: 'center',
        overflow: 'hidden',
        position: 'absolute',
    },
    Content: {
        padding: 20,
        width: '100%',
    },
    Header: {
        height: 75,
        width: 100,
        backgroundColor: '#fff',
    },
    Image: {
        width: 48,
        height: 48,
        position: 'absolute',
        top: 20,
    },
    Title: {
        color: '#1e1e1e',
        fontSize: 18,
        fontWeight: '600',
        fontStyle: 'normal',
        textAlign: 'center',
        lineHeight: 24,
        marginBottom: 10,
    },
    Desc: {
        color: '#111111',
        fontSize: 16,
        fontWeight: '400',
        fontStyle: 'normal',
        textAlign: 'center',
        lineHeight: 24,
    },
    Button: {
        flex: 1,
        height: 48,
        justifyContent: 'center',
        alignItems: 'center',
        marginTop: 20,
        borderRadius: 8,
        backgroundColor: '#702c91',
    },
    TextButton: {
        color: '#ffffff',
        fontFamily: 'AvenirNext-DemiBold',
        fontSize: 16,
        fontWeight: '600',
        fontStyle: 'normal',
        textAlign: 'center',
        lineHeight: 20,
    },
    successButtonStyle: {
        backgroundColor: '#702c91',
    },
    dangerButtonStyle: {
        backgroundColor: '#702c91',
    },
    warningButtonStyle: {
        backgroundColor: '#702c91',
    },
    confirm: {
        backgroundColor: 'transparent',
        color: '#111111',
    },
    confirmText: {
        color: '#111111',
    },

});

export default Popup;
